useDynLib(edgemodelr, .registration = TRUE)
importFrom(Rcpp, evalCpp)
importFrom(utils, download.file, flush.console, tail, askYesNo, read.csv, write.csv, head)
importFrom(tools, R_user_dir)
export(edge_load_model)
export(edge_completion)
export(edge_free_model)
export(is_valid_model)
export(edge_download_model)
export(edge_list_models)
export(edge_quick_setup)
export(edge_download_url)
export(edge_stream_completion)
export(edge_chat_stream)
export(build_chat_prompt)
export(edge_clean_cache)
export(edge_cache_info)
export(edge_set_verbose)
export(edge_benchmark)
export(edge_find_gguf_models)
export(edge_find_ollama_models)
export(edge_load_ollama_model)
export(edge_small_model_config)
export(edge_simd_info)
export(edge_install_cuda)
export(edge_install_cuda_toolkit)
export(edge_reload_cuda)
export(edge_cuda_info)
export(edge_grammar_completion)
export(edge_json_grammar)
export(edge_extract)
export(edge_classify)
export(edge_embeddings)
export(edge_similarity)
export(edge_model_n_embd)
export(edge_similarity_matrix)
export(edge_map)
export(edge_extract_batch)
export(edge_index_documents)
export(edge_search)
export(edge_ask)
export(edge_chat_completion)
export(edge_serve)
S3method(print, edge_index)
